]> ruderich.org/simon Gitweb - config/dotfiles.git/commitdiff
xmonad.hs: Improved way to switch to specific layouts.
authorSimon Ruderich <simon@ruderich.org>
Mon, 13 Jun 2011 12:03:52 +0000 (14:03 +0200)
committerSimon Ruderich <simon@ruderich.org>
Mon, 13 Jun 2011 12:03:52 +0000 (14:03 +0200)
No functional changes.

xmonad.hs

index 367c93be01aa7c2d3efa19fa28f3a879e5c7e3b7..d8f4d2dd9ad3859334387804ef4d171814f520cb 100644 (file)
--- a/xmonad.hs
+++ b/xmonad.hs
@@ -3,7 +3,8 @@
 -- Should work fine with XMonad 0.7 and above.
 
 
-import XMonad
+-- "hiding" necessary for LayoutCombinators.
+import XMonad hiding ( (|||) )
 -- Necessary for reflectVert.
 import XMonad.Layout.Reflect
 -- Necessary for avoidMaster.
@@ -20,6 +21,10 @@ import XMonad.Util.EZConfig
 import XMonad.Hooks.SetWMName
 -- Necessary for toggleWS.
 import XMonad.Actions.CycleWS
+-- Necessary for named.
+import XMonad.Layout.Named
+-- Necessary for JumpToLayout.
+import XMonad.Layout.LayoutCombinators
 
 
 -- Prevent new windows from spawning in the master pane. Taken from
@@ -34,7 +39,8 @@ avoidMaster = W.modify' $ \c -> case c of
 
 -- Create my custom layout.
 --
--- Only use horizontal (Mirror tiled) and fullscreen layouts.
+-- Only use horizontal (Mirror tiled) and fullscreen layouts, but allow
+-- switching to other layouts with bindings.
 --
 -- The master pane is at the top of the screen. To make sure new windows don't
 -- spawn in the master pane avoidMaster (see below) is used. Borders are only
@@ -43,10 +49,12 @@ avoidMaster = W.modify' $ \c -> case c of
 -- Thanks to jrick in #xmonad on Freenode (2009-06-29 22:19 CEST) for telling
 -- me how to remove the vertical tiled layout.
 --
--- toggleLayouts is used to allow switching to vertical tiled layout but not
--- using it with meta-space (see below in key bindings). Thanks to ml| in
--- #xmonad on Freenode (2010-06-14 09:49 CEST) how to use toggleLayouts.
-myLayoutHook = toggleLayouts tiled $ smartBorders $ Mirror tiled ||| Full
+-- JumpToLayout (from LayoutCombinators) is used to jump to specific layouts,
+-- thanks to aavogt in #xmonad on Freenode (2011-06-12 22:13 CEST).
+--
+-- named is used to name layouts which allows switching to a specific layout
+-- (see below), thanks to vav in #xmonad on Freenode (2011-06-12 22:28 CEST).
+myLayoutHook = named "Default" (smartBorders $ Mirror tiled) ||| Full ||| named "Vertical" tiled
     where
     -- Default tiling algorithm partitions the screen into two panes.
     tiled   = Tall nmaster delta ratio
@@ -82,10 +90,24 @@ myManageHook = composeOne
     , return True -?> doF W.focusDown
     ]
 
+-- Switch to next layout with descriptions in desc, other layouts are skipped.
+-- This allows switching to some layouts with mappings but excluding them from
+-- meta-space (which gets mapped to this function). Thanks to aavogt in
+-- #xmonad on Freenode for this function (2010-06-13 12:45 CEST), modified to
+-- take list of layouts to switch to, not layouts to exclude.
+nextLayoutIncluding descs =
+    do broadcastMessage NextLayout
+       d <- gets (description . W.layout . W.workspace . W.current . windowset)
+       if d `elem` descs
+           then refresh
+           else nextLayoutIncluding descs
+
 myKeys = [
-        -- Switch to additional layout (vertical tiled) defined by
-        -- toggleLayouts above.
-        ((mod4Mask, xK_v), sendMessage ToggleLayout)
+        -- Switch to next layout, but only use the listed layouts.
+        ((mod4Mask, xK_space), nextLayoutIncluding ["Default", "Full"])
+        -- Switch to vertical tiled layout.
+      , ((mod4Mask, xK_v), sendMessage $ JumpToLayout "Vertical")
+
         -- Switch to last active workspace, thanks to moljac024 in #xmonad on
         -- Freenode (2010-12-18 14:45 CET).
       , ((mod4Mask, xK_f), toggleWS)